"""Module-level constants."""
EARTHRADIUS = 6371000  # m
SECPERYEAR = 60 * 60 * 24 * 365.24219  # s
STEFAN_BOLTZMANN = 5.670374419e-8  # W m-2 K-4
